/*SAMPLE CODE*/
/*
Paper 2182-2015
Using the SAS Output Delivery System (ODS) and the TEMPLATE Procedure to Replace Dynamic Data Exchange (DDE)
Peter Timusk, Centre for Special Business Projects, Statistics Canada
*/

/*
USING THE TEMPLATE PROCEDURE

Throughout we will show a simple PROC TEMPLATE and a DEFINE STYLE to make a new STYLE element using 
various STYLE attributes to format Excel. This is the technique and code used by, Nate Derby and 
Colleen McGahan in their 2013 SAS Global Forum paper: Maintaining Formats when Exporting Data from 
SAS into Microsoft Excel, also with the Class dataset.  We will first apply a numeric format as 
these authors did, then extend this to a font format, then a cell format and finally a font 
justification format. Then we will use all of these together to end the examples. For many more 
possible formats see the references section.
FORMATING NUMBERS
Here we use PROC TEMPLATE and a STYLE element to format two variables height and weight from the 
Class dataset with the STYLE element data_num to display two decimal places in the Excel output:
*/   
   proc template;
   	define style styles.mystyle;
   		parent = styles.default;
   		style data_num from data / tagattr='format:0.00' ;
   	end;
   quit;
   ods tagsets.excelxp file="&folder output from excelxp, numeric formatting
   with proc templatenumberformat.xls" style=mystyle ;
   proc print data=sashelp.class;
   	var name sex age;
   	var height weight / style( data )=data_num;
   run;
 ods tagsets.excelxp close;
/*(NOTE: the code in this paper is drawn from examples in (Derby &  McGahan, 2013), (DelGobbo, 2012) 
 and SAS documentation and then extended to other formats.)
*/

/*************/
/*
FORMATING FONTS
Here we use the PROC TEMPLATE and a STYLE element to format the variable age from the Class dataset 
 with the STYLE element super_up to appear as superscripted data points in the Excel output:
*/

 proc template;
   	define style styles.mystyle;
   		parent = styles.default;
   		style super_up from data / fontsize= 8pt verticalalign=top;
   	end;
   quit;
   ods tagsets.excelxp file="&folder output from excelxp, font formatting
   with proc templatesuperup.xls" style=mystyle ;
   proc print data=sashelp.class;
   	var name sex;
   	var age / style( data )=super_up;
   run;
 ods tagsets.excelxp close;


/******************/
/*FORMATING CELLS
Here we format a cell with borders. Again we use the PROC TEMPLATE and a STYLE element to format 
 the cells in an Excel workbook with a border:
*/
proc template;
   	define style styles.mystyletable;
   		parent = styles.default;
style borders from data / borderleftwidth=1pt          borderrightwidth=1pt borderbottomwidth=1pt;
   	end;
   quit;
   ods tagsets.excelxp file="&folder output from excelxp, numeric formatting
   with proc templateborderscell.xls" style=mystyletable;
   proc print data=sashelp.class;
   	var name sex age height weight/ style( data )=borders ; 
   run;
   ods tagsets.excelxp close;


/*********************************/
/*
FORMATING JUSTIFICATION OF FONTS 
Here we use the PROC TEMPLATE and a STYLE element to format the justification of data values. 
   Here we justify left the age variable in the Class dataset. We can justify left or right or 
   center with justify attributes.
*/
proc template;
   	define style styles.mystyletable;
   		parent = styles.default;
    		style just_left  from data / just=left;
   	end;
   quit;
   ods tagsets.excelxp file="&folder output from excelxp, font formatting
    with proc templatejustifyleft.xls" style=mystyletable ;
   proc print data=sashelp.class;
   	var name sex;  
   	var age /   style( data )=just_left   ;     
      var height weight ;      
     
   run;
   ods tagsets.excelxp close;

/*********************************************/
/*
FORMATING MULTIPLE ATTRIBUTES AT THE SAME TIME 
Here we use the PROC TEMPLATE and a STYLE element to use all the previous formats and apply 
   these all to the last column the weight variable column.
*/
proc template;
   	define style styles.mystyletable;
   		parent = styles.default;
style all_formats from data / just=left tagattr='format:0.00' fontsize= 6pt verticalalign=top borderleftwidth=1pt          borderrightwidth=1pt borderbottomwidth=1pt;
   	end;
   quit;
   ods tagsets.excelxp file="&folder output from excelxp, all formatting
   with proc templateallformats.xls" style=mystyletable ;
   proc print data=sashelp.class;
   	var name sex age height;
var weight/ style( data )=all_formats ; 
   run;
   ods tagsets.excelxp close;
